parade.template.workspace.jupyter.ipython.profile\_parade package
=================================================================

Module contents
---------------

.. automodule:: parade.template.workspace.jupyter.ipython.profile_parade
    :members:
    :undoc-members:
    :show-inheritance:
